@@ -1,5 +1,5 @@
 print.etasclass<-function(x,...){
-    if(class(x)!="etasclass")stop(" argument x must be an etasclass object")
+  if (!inherits(x,"etasclass"))stop(" argument x must be an etasclass object")
     cat(x$description,"\n")
     cat("Execution started: ",format(x$time.start))
     cat("Elapsed time of execution (hours)  ",round(as.numeric(x$time.elapsed,units="hours"),3),"\n")
